@@ -2,13 +2,11 @@
 # 2.0, and the BSD License. See the LICENSE file in the root of this repository
 # for complete details.
 
-from __future__ import absolute_import, division, print_function
 
 import abc
+import datetime
 from enum import Enum
 
-import six
-
 
 class LogEntryType(Enum):
     X509_CERTIFICATE = 0
@@ -19,28 +17,27 @@ class Version(Enum):
     v1 = 0
 
 
-@six.add_metaclass(abc.ABCMeta)
-class SignedCertificateTimestamp(object):
+class SignedCertificateTimestamp(metaclass=abc.ABCMeta):
     @abc.abstractproperty
-    def version(self):
+    def version(self) -> Version:
         """
         Returns the SCT version.
         """
 
     @abc.abstractproperty
-    def log_id(self):
+    def log_id(self) -> bytes:
         """
         Returns an identifier indicating which log this SCT is for.
         """
 
     @abc.abstractproperty
-    def timestamp(self):
+    def timestamp(self) -> datetime.datetime:
         """
         Returns the timestamp for this SCT.
         """
 
     @abc.abstractproperty
-    def entry_type(self):
+    def entry_type(self) -> LogEntryType:
         """
         Returns whether this is an SCT for a certificate or pre-certificate.
         """
