@@ -2,7 +2,6 @@
 # 2.0, and the BSD License. See the LICENSE file in the root of this repository
 # for complete details.
 
-from __future__ import absolute_import, division, print_function
 
 import binascii
 
@@ -81,7 +80,7 @@ class TestCMAC(object):
 
         cmac = CMAC(AES(binascii.unhexlify(key)), backend)
         cmac.update(binascii.unhexlify(message))
-        assert cmac.verify(binascii.unhexlify(output)) is None
+        cmac.verify(binascii.unhexlify(output))
 
     @pytest.mark.supported(
         only_if=lambda backend: backend.cmac_algorithm_supported(
@@ -123,7 +122,7 @@ class TestCMAC(object):
 
         cmac = CMAC(TripleDES(binascii.unhexlify(key)), backend)
         cmac.update(binascii.unhexlify(message))
-        assert cmac.verify(binascii.unhexlify(output)) is None
+        cmac.verify(binascii.unhexlify(output))
 
     @pytest.mark.supported(
         only_if=lambda backend: backend.cmac_algorithm_supported(
@@ -146,7 +145,7 @@ class TestCMAC(object):
     def test_invalid_algorithm(self, backend):
         key = b"0102030405"
         with pytest.raises(TypeError):
-            CMAC(ARC4(key), backend)
+            CMAC(ARC4(key), backend)  # type: ignore[arg-type]
 
     @pytest.mark.supported(
         only_if=lambda backend: backend.cmac_algorithm_supported(
@@ -182,10 +181,10 @@ class TestCMAC(object):
         cmac = CMAC(AES(key), backend)
 
         with pytest.raises(TypeError):
-            cmac.update(u"")
+            cmac.update("")  # type: ignore[arg-type]
 
         with pytest.raises(TypeError):
-            cmac.verify(u"")
+            cmac.verify("")  # type: ignore[arg-type]
 
     @pytest.mark.supported(
         only_if=lambda backend: backend.cmac_algorithm_supported(
