@@ -2,12 +2,13 @@
 # 2.0, and the BSD License. See the LICENSE file in the root of this repository
 # for complete details.
 
-from hypothesis import given
+from hypothesis import HealthCheck, given, settings
 from hypothesis.strategies import binary
 
 from cryptography.fernet import Fernet
 
 
+@settings(suppress_health_check=[HealthCheck.too_slow], deadline=None)
 @given(binary())
 def test_fernet(data):
     f = Fernet(Fernet.generate_key())
