@@ -2,7 +2,6 @@
 # 2.0, and the BSD License. See the LICENSE file in the root of this repository
 # for complete details.
 
-from __future__ import absolute_import, division, print_function
 
 import base64
 import calendar
@@ -12,9 +11,9 @@ import time
 
 import iso8601
 
-import pytest
+import pretend
 
-import six
+import pytest
 
 from cryptography.fernet import Fernet, InvalidToken, MultiFernet
 from cryptography.hazmat.backends import default_backend
@@ -58,7 +57,7 @@ class TestFernet(object):
         actual_token = f._encrypt_from_parts(
             src.encode("ascii"),
             calendar.timegm(iso8601.parse_date(now).utctimetuple()),
-            b"".join(map(six.int2byte, iv)),
+            bytes(iv),
         )
         assert actual_token == token.encode("ascii")
 
@@ -113,17 +112,15 @@ class TestFernet(object):
     def test_unicode(self, backend):
         f = Fernet(base64.urlsafe_b64encode(b"\x00" * 32), backend=backend)
         with pytest.raises(TypeError):
-            f.encrypt(u"")
+            f.encrypt("")  # type: ignore[arg-type]
         with pytest.raises(TypeError):
-            f.decrypt(u"")
+            f.decrypt("")  # type: ignore[arg-type]
 
     def test_timestamp_ignored_no_ttl(self, monkeypatch, backend):
         f = Fernet(base64.urlsafe_b64encode(b"\x00" * 32), backend=backend)
         pt = b"encrypt me"
         token = f.encrypt(pt)
-        ts = "1985-10-26T01:20:01-07:00"
-        current_time = calendar.timegm(iso8601.parse_date(ts).utctimetuple())
-        monkeypatch.setattr(time, "time", lambda: current_time)
+        monkeypatch.setattr(time, "time", pretend.raiser(ValueError))
         assert f.decrypt(token, ttl=None) == pt
 
     def test_ttl_required_in_decrypt_at_time(self, monkeypatch, backend):
@@ -131,7 +128,11 @@ class TestFernet(object):
         pt = b"encrypt me"
         token = f.encrypt(pt)
         with pytest.raises(ValueError):
-            f.decrypt_at_time(token, ttl=None, current_time=int(time.time()))
+            f.decrypt_at_time(
+                token,
+                ttl=None,  # type: ignore[arg-type]
+                current_time=int(time.time()),
+            )
 
     @pytest.mark.parametrize("message", [b"", b"Abc!", b"\x00\xFF\x00\x80"])
     def test_roundtrips(self, message, backend):
@@ -187,7 +188,9 @@ class TestMultiFernet(object):
         with pytest.raises(InvalidToken):
             f.decrypt_at_time(token, ttl=1, current_time=102)
         with pytest.raises(ValueError):
-            f.decrypt_at_time(token, ttl=None, current_time=100)
+            f.decrypt_at_time(
+                token, ttl=None, current_time=100  # type: ignore[arg-type]
+            )
 
     def test_no_fernets(self, backend):
         with pytest.raises(ValueError):
@@ -195,7 +198,7 @@ class TestMultiFernet(object):
 
     def test_non_iterable_argument(self, backend):
         with pytest.raises(TypeError):
-            MultiFernet(None)
+            MultiFernet(None)  # type: ignore[arg-type]
 
     def test_rotate(self, backend):
         f1 = Fernet(base64.urlsafe_b64encode(b"\x00" * 32), backend=backend)
