@@ -2,7 +2,6 @@
 # 2.0, and the BSD License. See the LICENSE file in the root of this repository
 # for complete details.
 
-from __future__ import absolute_import, division, print_function
 
 import binascii
 
@@ -13,9 +12,11 @@ from cryptography.hazmat.backends.interfaces import CMACBackend
 from cryptography.hazmat.primitives.ciphers.algorithms import AES
 from cryptography.hazmat.primitives.cmac import CMAC
 
+from .utils import wycheproof_tests
+
 
 @pytest.mark.requires_backend_interface(interface=CMACBackend)
-@pytest.mark.wycheproof_tests("aes_cmac_test.json")
+@wycheproof_tests("aes_cmac_test.json")
 def test_aes_cmac(backend, wycheproof):
     key = binascii.unhexlify(wycheproof.testcase["key"])
     msg = binascii.unhexlify(wycheproof.testcase["msg"])
